library tool.dev;

import 'dart:async';

import 'package:dart_dev/dart_dev.dart';

const _unitTestGeneratedRunner = 'generated_test_runner';

Future<Null> main(List<String> args) async {
  config.analyze
    // Do not analyze 'test' since it only has the generated test runner (which breaks some linter rules)
    ..entryPoints = ['example/', 'lib/', 'lib/src/', 'tool/', 'test/src/']
    ..strong = true;

  // default options work fine
  config.coverage
    // Generating the test runner avoids the need to commit (and check that it is up to date) the test runner file
    ..before = <String>['pub run dart_dev gen-test-runner'];

  config.format
    // Run at 'test/src' to avoid formatting the generated test runner (which generates "out of spec")
    ..paths = ['example/', 'lib/', 'tool/', 'test/src/']
    ..lineLength = 100;

  config.genTestRunner.configs = [
    new TestRunnerConfig(
      // This is a hack to ignore the fact that the generated test runner has imports out of order.
      // The exclude option for analysis_options.yaml was not working correctly, there are a number
      // of dartlang issues about issues/difficulties around the exclude system.
      dartHeaders: ['// ignore_for_file: directives_ordering'],
      directory: 'test',
      env: Environment.vm,
      filename: _unitTestGeneratedRunner,
    ),
  ];
  config.test
    // Generating the test runner avoids the need to commit (and check that it is up to date) the test runner file
    ..before = <String>['pub run dart_dev gen-test-runner']
    ..platforms = ['vm']
    ..unitTests = ['test/$_unitTestGeneratedRunner.dart'];

  config.taskRunner
    ..tasksToRun = [
      'pub run dart_dev format --check',
      // Ignore unused coverage, dart_style and dartdoc dependencies, then are not imported but rather used for executables
      'pub run dependency_validator --ignore coverage,dart_style,dartdoc',
      'pub run dart_dev analyze',
      // Run coverage so it can be uploaded to codecov
      'pub run dart_dev coverage --no-html',
      // Run docs task to ensure docs can be built
      'pub run dart_dev docs --no-open',
      // Verifies the package can be published and has no transitive dependencies
      'pub publish --dry-run'
    ];

  await dev(args);
}
